# 📖 Summary
- [📖 Summary](#-summary)
- [💼 About Lever](#-about-lever)
  - [😍 Why is it a big deal for Lever customers & partners?](#-why-is-it-a-big-deal-for-lever-customers--partners)
- [🔧 How does it work?](#-how-does-it-work)
  - [📊 Data integration capabilities:](#-data-integration-capabilities)
  - [🧠 Artificial Intelligence capabilities:](#-artificial-intelligence-capabilities)
- [🔌 Connector Actions](#-connector-actions)
- [💍 Quick Start Examples](#-quick-start-examples)
- [🔗 Useful Links](#-useful-links)
- [👏 Special Thanks](#-special-thanks)


# 💼 About Lever

> Lever is a modern recruitment platform that helps companies streamline their hiring process.


## 😍 Why is it a big deal for Lever customers & partners?

This new connector will enable:
- ⚡ A Fastlane Talent & Workforce data integration for Lever customers & partners
- 🤖 Cutting-edge AI-powered Talent Experiences & Recruiter Experiences for Lever customers

#  🔧 How does it work?
## 📊 Data integration capabilities:
- ⬅️ Send Profiles data from Lever to a Destination of your choice.
- ➡️ Send Profiles data from a Source of your choice to Lever.
- ⬅️ Send Jobs data from Lever to a Destination of your choice.
- ➡️ Send Jobs data from a Source of your choice to Lever.


## 🧠 Artificial Intelligence capabilities:
- Extract, Structure, and Categorize Talent & Workforce data
- Search, Score, and Match Profiles & Jobs with our APIs and AI Widgets (**Matching Custom Tab in Lever**)


# 🔌 Connector Actions
<p align="center">

| Action | Description |
| ------- | ----------- |
| [**Pull job list**](docs/pull_job_list.md) | Retrieves all jobs via the Lever API and sends them to the Hrflow.ai Board. |
| [**Push profile**](docs/push_profile.md) | Writes a profile from the Hrflow.ai Source to Lever via the API. |
| [**Pull profile list**](docs/pull_profile_list.md) | Read a profile from Lever Source to Hrflow.ai via the API. |


</p>


# 💍 Quick Start Examples

To make sure you can successfully run the latest versions of the example scripts, you have to **install the package from PyPi**.


To browse the examples of actions corresponding to released versions of 🤗 this connector, you just need to import the module like this :


Once the connector module is imported, you can leverage all the different actions that it offers.

For more code details checkout connector code.


# 🔗 Useful Links

- 📄Visit [Lever](https://www.lever.com/) to learn more.
- 💻 [Connector code](https://github.com/Riminder/hrflow-connectors/tree/master/src/hrflow_connectors/connectors/lever) on our Github.


# 👏 Special Thanks
- 💻 HrFlow.ai : Abdellahi Mezid - Software Engineer
- 🤝 Lever : Support Lever
